@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Vocabulary::Applicator;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema Applicator vocabulary
 
-our $VERSION = '0.590';
+our $VERSION = '0.591';
 
 use 5.020;
 use Moo;
@@ -25,12 +25,12 @@ use namespace::clean;
 
 with 'JSON::Schema::Modern::Vocabulary';
 
-sub vocabulary {
+sub vocabulary ($class) {
   'https://json-schema.org/draft/2019-09/vocab/applicator' => 'draft2019-09',
   'https://json-schema.org/draft/2020-12/vocab/applicator' => 'draft2020-12';
 }
 
-sub evaluation_order { 3 }
+sub evaluation_order ($class) { 3 }
 
 # the keyword order is arbitrary, except:
 # - if must be evaluated before then, else
@@ -550,7 +550,7 @@ JSON::Schema::Modern::Vocabulary::Applicator - Implementation of the JSON Schema
 
 =head1 VERSION
 
-version 0.590
+version 0.591
 
 =head1 DESCRIPTION
 
