@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Vocabulary::FormatAnnotation;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema Format-Annotation vocabulary
 
-our $VERSION = '0.590';
+our $VERSION = '0.591';
 
 use 5.020;
 use Moo;
@@ -25,14 +25,14 @@ use namespace::clean;
 
 with 'JSON::Schema::Modern::Vocabulary';
 
-sub vocabulary {
+sub vocabulary ($class) {
   'https://json-schema.org/draft/2019-09/vocab/format' => 'draft2019-09',
   'https://json-schema.org/draft/2020-12/vocab/format-annotation' => 'draft2020-12';
 }
 
-sub evaluation_order { 2 }
+sub evaluation_order ($class) { 2 }
 
-sub keywords {
+sub keywords ($class, $spec_version) {
   qw(format);
 }
 
@@ -83,7 +83,7 @@ JSON::Schema::Modern::Vocabulary::FormatAnnotation - Implementation of the JSON
 
 =head1 VERSION
 
-version 0.590
+version 0.591
 
 =head1 DESCRIPTION
 
