@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Vocabulary::Unevaluated;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema Unevaluated vocabulary
 
-our $VERSION = '0.590';
+our $VERSION = '0.591';
 
 use 5.020;
 use Moo;
@@ -22,11 +22,11 @@ use namespace::clean;
 
 with 'JSON::Schema::Modern::Vocabulary';
 
-sub vocabulary {
+sub vocabulary ($class) {
   'https://json-schema.org/draft/2020-12/vocab/unevaluated' => 'draft2020-12';
 }
 
-sub evaluation_order { 7 }
+sub evaluation_order ($class) { 7 }
 
 # This vocabulary should be evaluated after the Applicator vocabulary.
 sub keywords ($class, $spec_version) {
@@ -157,7 +157,7 @@ JSON::Schema::Modern::Vocabulary::Unevaluated - Implementation of the JSON Schem
 
 =head1 VERSION
 
-version 0.590
+version 0.591
 
 =head1 DESCRIPTION
 
